@@ -182,7 +182,7 @@ class FileGenerator:
     def __init__(self, path):
         self.path = path
         self.fp = file(path, "rb")
-        self.map = mmap.mmap(self.fp.fileno(), 0, prot=mmap.PROT_READ)
+        self.map = mmap.mmap(self.fp.fileno(), 0, access=mmap.ACCESS_READ)
 
     def __len__(self):
         return len(self.map)
@@ -765,11 +765,12 @@ class _Message(object):
     def resolve(self, settings, request_host):
         tokens = self.tokens[:]
         if not self.raw:
-            if self.body and not utils.get_header("Content-Length", self.headers):
+            if not utils.get_header("Content-Length", self.headers):
+                length = 0 if not self.body else len(self.body.value.get_generator(settings))
                 tokens.append(
                     Header(
                         ValueLiteral("Content-Length"),
-                        ValueLiteral(str(len(self.body.value.get_generator(settings)))),
+                        ValueLiteral(str(length)),
                     )
                 )
             if request_host:
