@@ -1,5 +1,5 @@
-import urllib, threading, re, logging, socket, sys, base64
-from netlib import tcp, http, odict, wsgi, certutils
+import urllib, threading, re, logging
+from netlib import tcp, http, wsgi, certutils
 import netlib.utils
 import version, app, language, utils
 
@@ -12,7 +12,7 @@ class SSLOptions:
     def __init__(self, certfile=None, keyfile=None, not_after_connect=None, request_client_cert=False):
         self.keyfile = keyfile or utils.data.path("resources/server.key")
         self.certfile = certfile or utils.data.path("resources/server.crt")
-        self.cert = certutils.SSLCert.from_pem(file(self.certfile, "r").read())
+        self.cert = certutils.SSLCert.from_pem(file(self.certfile, "rb").read())
         self.not_after_connect = not_after_connect
         self.request_client_cert = request_client_cert
 
@@ -123,8 +123,8 @@ class PathodHandler(tcp.BaseHandler):
         )
 
         try:
-            content = http.read_http_body_request(
-                        self.rfile, self.wfile, headers, httpversion, None
+            content = http.read_http_body(
+                        self.rfile, headers, None, True
                     )
         except http.HttpError, s:
             s = str(s)
@@ -158,13 +158,13 @@ class PathodHandler(tcp.BaseHandler):
             cc = wsgi.ClientConn(self.client_address)
             req = wsgi.Request(cc, "http", method, path, headers, content)
             sn = self.connection.getsockname()
-            app = wsgi.WSGIAdaptor(
+            a = wsgi.WSGIAdaptor(
                 self.server.app,
                 sn[0],
                 self.server.port,
                 version.NAMEVERSION
             )
-            app.serve(req, self.wfile)
+            a.serve(req, self.wfile)
             return True, None
 
     def _log_bytes(self, header, data, hexdump):
@@ -257,7 +257,7 @@ class Pathod(tcp.TCPServer):
                 except re.error:
                     raise PathodError("Invalid regex in anchor: %s"%i[0])
                 try:
-                    aresp = language.parse_response(self.request_settings, i[1])
+                    language.parse_response(self.request_settings, i[1])
                 except language.ParseException, v:
                     raise PathodError("Invalid page spec in anchor: '%s', %s"%(i[1], str(v)))
                 self.anchors.append((arex, i[1]))
@@ -268,7 +268,7 @@ class Pathod(tcp.TCPServer):
         """
         try:
             l = req.maximum_length(settings)
-        except language.FileAccessDenied, v:
+        except language.FileAccessDenied:
             return "File access denied."
         if self.sizelimit and l > self.sizelimit:
             return "Response too large."
