@@ -1,6 +1,6 @@
 import tempfile, os, shutil
 from contextlib import contextmanager
-from libpathod import utils, test, pathoc
+from libpathod import utils, test, pathoc, pathod
 import requests
 
 class DaemonTests:
@@ -10,12 +10,15 @@ class DaemonTests:
     ssl = False
     timeout = None
     hexdump = False
+    not_after_connect = False
     @classmethod
     def setUpAll(self):
+        so = pathod.SSLOptions(not_after_connect = self.not_after_connect)
         self.d = test.Daemon(
             staticdir=test_data.path("data"),
-            anchors=[("/anchor/.*", "202")],
+            anchors=[("/anchor/.*", "202:da")],
             ssl = self.ssl,
+            ssloptions = so,
             sizelimit=1*1024*1024,
             noweb = self.noweb,
             noapi = self.noapi,
@@ -44,11 +47,11 @@ class DaemonTests:
     def get(self, spec):
         return requests.get(self.d.p(spec), verify=False)
 
-    def pathoc(self, spec, timeout=None):
-        c = pathoc.Pathoc("localhost", self.d.port)
-        c.connect()
-        if self.ssl:
-            c.convert_to_ssl()
+    def pathoc(self, spec, timeout=None, connect_to=None, ssl=None):
+        if ssl is None:
+            ssl = self.ssl
+        c = pathoc.Pathoc("localhost", self.d.port, ssl=ssl)
+        c.connect(connect_to)
         if timeout:
             c.settimeout(timeout)
         return c.request(spec)
